atmospheric platformer game with algorithmic environment creation
inspired by `knytt`_

Code is based on `Pygame-Demo`_ by Dan Wolfe.

Usage
=====

Install the game::

    python setup.py install

After installation you can start the game using ``platformer``. Use left and
right keys to move and space to jump. If you stand next to a wall you
can also use up and down to climb the wall.

.. _knytt: http://nifflas.ni2.se/
.. _Pygame-Demo: https://github.com/danthewolfe/Pygame-Demo
